/*
 *  /MathJax/localization/cs/MathMenu.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("cs","MathMenu",{version:"2.7.5",isLoaded:true,strings:{Show:"Zobrazit matematiku jako",MathMLcode:"K\u00F3d MathML",OriginalMathML:"P\u016Fvodn\u00ED MathML",TeXCommands:"P\u0159\u00EDkazy TeXu",AsciiMathInput:"Vstup AsciiMathML",Original:"P\u016Fvodn\u00ED podoba",ErrorMessage:"Chybov\u00E9 hl\u00E1\u0161en\u00ED",Annotation:"Anotace",TeX:"TeX",StarMath:"StarMath",Maple:"Maple",ContentMathML:"V\u00FDznamov\u00E9 MathML",OpenMath:"OpenMath",texHints:"Zobrazovat v MathML n\u00E1pov\u011Bdy TeXu",Settings:"Nastaven\u00ED matematiky",ZoomTrigger:"Aktivace zoomu",Hover:"Najet\u00EDm my\u0161\u00ED",Click:"Kliknut\u00EDm",DoubleClick:"Dvojklikem",NoZoom:"Bez zoomu",TriggerRequires:"Aktivace vy\u017Eaduje:",Option:"Option",Alt:"Alt",Command:"Command",Control:"Control",Shift:"Shift",ZoomFactor:"M\u00EDra zoomu",Renderer:"Vykreslov\u00E1n\u00ED matematiky",MPHandles:"MathPlayer m\u00E1 zpracov\u00E1vat:",MenuEvents:"Ud\u00E1losti menu",MouseEvents:"Ud\u00E1losti my\u0161i",MenuAndMouse:"Ud\u00E1losti my\u0161i a menu",FontPrefs:"Nastaven\u00ED p\u00EDsem",ForHTMLCSS:"U HTML-CSS:",Auto:"Automaticky",TeXLocal:"TeX (lok\u00E1ln\u00ED)",TeXWeb:"TeX (web)",TeXImage:"TeX (obr\u00E1zek)",STIXLocal:"STIX (lok\u00E1ln\u00ED)",STIXWeb:"STIX (web)",AsanaMathWeb:"Asana Math (web)",GyrePagellaWeb:"Gyre Pagella (web)",GyreTermesWeb:"Gyre Termes (web)",LatinModernWeb:"Latin Modern (web)",NeoEulerWeb:"Neo Euler (web)",ContextMenu:"Kontextov\u00E9 menu",Browser:"Prohl\u00ED\u017Ee\u010D",Scale:"M\u011B\u0159\u00EDtko pro ve\u0161kerou matematiku\u2026",Discoverable:"Zv\u00FDraznit p\u0159i najet\u00ED my\u0161\u00ED",Locale:"Jazyk",LoadLocale:"Na\u010D\u00EDst z URL\u2026",About:"O MathJaxu",Help:"N\u00E1pov\u011Bda k MathJaxu",localTeXfonts:"pou\u017E\u00EDvaj\u00ED se lok\u00E1ln\u00ED p\u00EDsma TeXu",webTeXfonts:"pou\u017E\u00EDvaj\u00ED se webov\u00E1 p\u00EDsma TeXu",imagefonts:"pou\u017E\u00EDvaj\u00ED se obr\u00E1zkov\u00E1 p\u00EDsma",localSTIXfonts:"pou\u017E\u00EDvaj\u00ED se lok\u00E1ln\u00ED p\u00EDsma STIX",webSVGfonts:"pou\u017E\u00EDvaj\u00ED se webov\u00E1 SVG p\u00EDsma",genericfonts:"pou\u017E\u00EDvaj\u00ED se generick\u00E1 unicodov\u00E1 p\u00EDsma",wofforotffonts:"p\u00EDsma woff nebo otf",eotffonts:"p\u00EDsma eot",svgfonts:"p\u00EDsma svg",WebkitNativeMMLWarning:"V\u00E1\u0161 prohl\u00ED\u017Ee\u010D patrn\u011B nepodporuje MathML, tak\u017Ee p\u0159epnut\u00ED na MathML v\u00FDstup m\u016F\u017Ee zp\u016Fsobit, \u017Ee bude matematika na t\u00E9to str\u00E1nce ne\u010Diteln\u00E1.",MSIENativeMMLWarning:"Ke zpracov\u00E1n\u00ED MathML v\u00FDstupu pot\u0159ebuje Internet Explorer z\u00E1suvn\u00FD modul MathPlayer.",OperaNativeMMLWarning:"Podpora MathML v Ope\u0159e je omezen\u00E1, tak\u017Ee p\u0159epnut\u00ED na MathML v\u00FDstup m\u016F\u017Ee zp\u016Fsobit, \u017Ee se n\u011Bkter\u00E9 v\u00FDrazy budou vykreslovat \u0161patn\u011B.",SafariNativeMMLWarning:"Vestav\u011Bn\u00E1 podpora MathML ve va\u0161em prohl\u00ED\u017Ee\u010Di neobsahuje v\u0161echny funkce pou\u017E\u00EDvan\u00E9 MathJaxem, tak\u017Ee se n\u011Bkter\u00E9 v\u00FDrazy mohou vykreslit chybn\u011B.",FirefoxNativeMMLWarning:"Vestav\u011Bn\u00E1 podpora MathML ve va\u0161em prohl\u00ED\u017Ee\u010Di neobsahuje v\u0161echny funkce pou\u017E\u00EDvan\u00E9 MathJaxem, tak\u017Ee se n\u011Bkter\u00E9 v\u00FDrazy mohou vykreslit chybn\u011B.",MSIESVGWarning:"Internet Explorer ve verzi star\u0161\u00ED ne\u017E IE9 nebo v re\u017Eimu emulace IE8 a star\u0161\u00ED nepodporuje SVG. P\u0159epnut\u00ED na SVG v\u00FDstup zp\u016Fsob\u00ED, \u017Ee se matematika nebude zobrazovat spr\u00E1vn\u011B.",LoadURL:"Na\u010D\u00EDst p\u0159eklad z URL:",BadURL:"URL by m\u011Blo v\u00E9st na JavaScriptov\u00FD soubor, kter\u00FD definuje data p\u0159ekladu MathJaxu. N\u00E1zvy JavaScriptov\u00FDch soubor\u016F by m\u011Bly kon\u010Dit \u201E.js\u201C.",BadData:"Nepoda\u0159ilo se na\u010D\u00EDst data p\u0159ekladu z %1",SwitchAnyway:"Chcete p\u0159esto p\u0159epnout vykreslov\u00E1n\u00ED?\n\n(Stiskn\u011Bte OK pro p\u0159epnut\u00ED, STORNO pro pokra\u010Dov\u00E1n\u00ED se st\u00E1vaj\u00EDc\u00EDm vykreslov\u00E1n\u00EDm.)",ScaleMath:"Ve\u0161kerou matematiku zobrazovat v m\u011B\u0159\u00EDtku (v porovn\u00E1n\u00ED s okoln\u00EDm textem)",NonZeroScale:"M\u011B\u0159\u00EDtko nem\u016F\u017Ee b\u00FDt nulov\u00E9",PercentScale:"M\u011B\u0159\u00EDtko by m\u011Blo b\u00FDt v procentech (nap\u0159\u00EDklad 120 %%)",IE8warning:"T\u00EDmto vypnete funkce MathJaxu pro zobrazen\u00ED menu a zv\u011Bt\u0161ov\u00E1n\u00ED, ale menu MathJaxu si budete moci zobrazit pomoc\u00ED Alt+kliknut\u00ED na rovnici.\n\nOpravdu zm\u011Bnit nastaven\u00ED MathPlayeru?",IE9warning:"T\u00EDmto vypnete kontextov\u00E9 menu MathJaxu, ale budete si ho moci zobrazit pomoc\u00ED Alt+kliknut\u00ED na rovnici.",NoOriginalForm:"P\u016Fvodn\u00ED podoba nen\u00ED dostupn\u00E1",Close:"Zav\u0159\u00EDt",EqSource:"Zdroj rovnice MathJax",CloseAboutDialog:"Zav\u0159\u00EDt okno o MathJaxu",FastPreview:"Rychl\u00FD n\u00E1hled",AssistiveMML:"Asistivn\u00ED MathML",InTabOrder:"Za\u0159adit do posloupnosti tabul\u00E1toru"}});MathJax.Ajax.loadComplete("[MathJax]/localization/cs/MathMenu.js");
